==> react-lds-8.7.0.tgz: package/es/components/Card/CardHeader.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Grid } from '../Grid';
import { MediaObject } from '../MediaObject';

var CardHeader = function CardHeader(_ref) {
  var children = _ref.children,
      className = _ref.className,
      icon = _ref.icon,
      titleClassName = _ref.titleClassName,
      titleProps = _ref.titleProps,
      title = _ref.title,
      rest = _objectWithoutProperties(_ref, ["children", "className", "icon", "titleClassName", "titleProps", "title"]);

  var LinkTag = titleProps.href ? 'a' : 'span';
  return React.createElement(Grid, _extends({}, rest, {
    className: cx(['slds-card__header', className])
  }), React.createElement(MediaObject, {
    className: "slds-has-flexi-truncate",
    figureLeft: icon
  }, title && React.createElement("h2", {
    className: "slds-card__header-title"
  }, React.createElement(LinkTag, _extends({}, titleProps, {
    className: cx(['slds-card__header-link', 'slds-truncate', titleClassName])
  }), React.createElement("span", null, title)))), children && React.createElement("div", {
    className: "slds-no-flex"
  }, children));
};

CardHeader.defaultProps = {
  children: null,
  className: null,
  icon: null,
  titleClassName: null,
  titleProps: {},
  title: null
};
CardHeader.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Renders in the right column
   */
  children: PropTypes.node,

  /**
   * Applied to top-level element `slds-card__header`
   */
  className: PropTypes.string,

  /**
   * Optional icon, should be `<Icon />`
   */
  icon: PropTypes.element,

  /**
   * Applied to `slds-card__header-link`
   */
  titleClassName: PropTypes.string,

  /**
   * Props passed to `slds-card__header-link`. If `href` is set, title will render as `a`, else `span`
   */
  titleProps: PropTypes.object,

  /**
   * Title text
   */
  title: PropTypes.element
} : {};
export default CardHeader;

==> react-lds-9.1.0.tgz: package/es/components/Card/CardHeader.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Grid } from '../Grid';
import { MediaObject } from '../MediaObject';

var CardHeader = function CardHeader(_ref) {
  var children = _ref.children,
      className = _ref.className,
      icon = _ref.icon,
      titleClassName = _ref.titleClassName,
      titleProps = _ref.titleProps,
      title = _ref.title,
      rest = _objectWithoutProperties(_ref, ["children", "className", "icon", "titleClassName", "titleProps", "title"]);

  var LinkTag = titleProps.href ? 'a' : 'span'; // The LDS sets `.slds-truncate` on the span, that does not work in praxis though

  return React.createElement(Grid, _extends({}, rest, {
    className: cx(['slds-card__header', className])
  }), React.createElement(MediaObject, {
    className: "slds-has-flexi-truncate",
    figureLeft: icon
  }, title && React.createElement("h2", {
    className: "slds-card__header-title slds-truncate"
  }, React.createElement(LinkTag, _extends({}, titleProps, {
    className: cx(['slds-card__header-link', titleClassName])
  }), React.createElement("span", null, title)))), children && React.createElement("div", {
    className: "slds-no-flex"
  }, children));
};

CardHeader.defaultProps = {
  children: null,
  className: null,
  icon: null,
  titleClassName: null,
  titleProps: {},
  title: null
};
CardHeader.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Renders in the right column
   */
  children: PropTypes.node,

  /**
   * Applied to top-level element `slds-card__header`
   */
  className: PropTypes.string,

  /**
   * Optional icon, should be `<Icon />`
   */
  icon: PropTypes.element,

  /**
   * Applied to `slds-card__header-link`
   */
  titleClassName: PropTypes.string,

  /**
   * Props passed to `slds-card__header-link`. If `href` is set, title will render as `a`, else `span`
   */
  titleProps: PropTypes.object,

  /**
   * Title text or element
   */
  title: PropTypes.node
} : {};
export default CardHeader;
